/**
 * Copyright 2008 Bluestem Software LLC.  All Rights Reserved.
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * 
 */

package org.bluestemsoftware.open.eoa.example.order.manager.service.vo;

import java.util.Date;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Map;
import java.util.Set;

/**
 * Contains state related to fulfillment of a 'customer order' within context of order manager
 * application.
 */
public class CustomerOrder {

    public static enum Status {
        ORDERED, ERROR, COMPLETE
    }

    private String orderNumber;
    private String emailAddress;
    private String zipCode;
    private Double shipCost;
    private Date estShipDate;
    private Date actualShipDate;
    private Status status;
    private Set<Item> items = new HashSet<Item>();
    private String error;
    private Map<String, OutstandingRequest> outstandingRequests;

    public CustomerOrder() {
    }

    /**
     * Constructs an order sans customer information, e.g. name and address, etc ... which is
     * elided to simplify example. Note that order number is generated by warehouse manager
     * application.
     * 
     * @param orderNumber
     * @param zipCode
     * @param items
     */
    public CustomerOrder(String orderNumber, String zipCode, Set<Item> items, double shipCost) {
        this.orderNumber = orderNumber;
        this.zipCode = zipCode;
        this.items = items;
        this.status = Status.ORDERED;
        this.shipCost = shipCost;
    }

    public Set<Item> getItems() {
        return items;
    }

    public void setZipCode(String zipCode) {
        this.zipCode = zipCode;
    }

    public void setItems(Set<Item> items) {
        this.items = items;
    }

    public String getOrderNumber() {
        return orderNumber;
    }

    public String getZipCode() {
        return zipCode;
    }

    public Status getStatus() {
        return status;
    }

    public void setStatus(Status status) {
        this.status = status;
    }

    public Double getShipCost() {
        return shipCost;
    }

    public Date getActualShipDate() {
        return actualShipDate;
    }

    public void setActualShipDate(Date actualShipDate) {
        this.actualShipDate = actualShipDate;
    }

    public Date getEstShipDate() {
        return estShipDate;
    }

    public void setEstShipDate(Date estShipDate) {
        this.estShipDate = estShipDate;
    }

    public String getError() {
        return error;
    }

    public void setError(String error) {
        this.error = error;
    }

    public void setOrderNumber(String orderNumber) {
        this.orderNumber = orderNumber;
    }

    public void setShipCost(Double shipCost) {
        this.shipCost = shipCost;
    }
    
    public String getEmailAddress() {
        return emailAddress;
    }
    
    public void setEmailAddress(String emailAddress) {
        this.emailAddress = emailAddress;
    }

    public void addOutstandingRequest(OutstandingRequest outstandingRequest) {
        if (outstandingRequests == null) {
            outstandingRequests = new HashMap<String, OutstandingRequest>();
        }
        outstandingRequests.put(outstandingRequest.getID(), outstandingRequest);
    }

    public OutstandingRequest getOutstandingRequest(String messageExchangeID) {
        if (outstandingRequests == null) {
            return null;
        }
        return outstandingRequests.get(messageExchangeID);
    }
    
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("actualShipDate: " + actualShipDate);
        sb.append(System.getProperty("line.separator"));
        sb.append("emailAddress: " + emailAddress);
        sb.append(System.getProperty("line.separator"));
        sb.append("error: " + error);
        sb.append(System.getProperty("line.separator"));
        sb.append("estShipDate: " + estShipDate);
        sb.append(System.getProperty("line.separator"));
        sb.append("items: " + items);
        sb.append(System.getProperty("line.separator"));
        sb.append("orderNumber: " + orderNumber);
        sb.append(System.getProperty("line.separator"));
        sb.append("shipCost: " + shipCost);
        sb.append(System.getProperty("line.separator"));
        sb.append("zipCode: " + zipCode);
        sb.append(System.getProperty("line.separator"));
        return sb.toString();
    }

}
