/**
 * Copyright 2008 Bluestem Software LLC.  All Rights Reserved.
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * 
 */

package org.bluestemsoftware.open.eoa.example.order.manager.service.vo;

/**
 * Value object used as an entry within catalog, i.e. quantity is zero and price is per item,
 * and as an item within an order, i.e. quantity > 0 and price is total price for item.
 */
public class Item {

    private String id;
    private String description;
    private float price;
    private int quantity;

    public Item() {
    }

    public Item(String id, String description) {
        this.id = id;
        this.description = description;
    }

    public Item(String id, String description, float price) {
        this.id = id;
        this.description = description;
        this.price = price;
    }

    public Item(String id, String description, float price, int quantity) {
        this.id = id;
        this.description = description;
        this.price = price;
        this.quantity = quantity;
    }

    public String getDescription() {
        return description;
    }

    public String getId() {
        return id;
    }

    public float getPrice() {
        return price;
    }

    public int getQuantity() {
        return quantity;
    }

    public void setQuantity(int quantity) {
        this.quantity = quantity;
    }

    public void setPrice(float price) {
        this.price = price;
    }

    public void setId(String id) {
        this.id = id;
    }

    public void setDescription(String description) {
        this.description = description;
    }
    
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("id: " + id);
        sb.append(System.getProperty("line.separator"));
        sb.append("description: " + description);
        sb.append(System.getProperty("line.separator"));
        sb.append("price: " + price);
        sb.append(System.getProperty("line.separator"));
        sb.append("quantity: " + quantity);
        return sb.toString();
    }


}
